@@ -10,6 +10,7 @@ import numpy
 from marshmallow import Schema, ValidationError, fields as marshmallow_fields, missing
 
 from . import field_validators, raw_nodes
+from .utils._docs import resolve_bioimageio_descrcription
 
 logger = logging.getLogger(__name__)
 
@@ -20,7 +21,8 @@ class DocumentedField:
     def __init__(
         self,
         *super_args,
-        bioimageio_description: str = "",
+        short_bioimageio_description: typing.Union[str, typing.Callable[[], str]] = "",
+        bioimageio_description: typing.Union[str, typing.Callable[[], str]] = "",
         bioimageio_description_order: typing.Optional[int] = None,
         bioimageio_maybe_required: bool = False,  # indicates that this field may be required, depending on other fields
         bioimageio_examples_valid: typing.Optional[
@@ -35,20 +37,17 @@ class DocumentedField:
         if self.__class__.__name__ not in bases:
             bases.insert(0, self.__class__.__name__)
 
+        # todo: support examples for documentation
         # if bioimageio_examples_valid is not None:
         #     valid_examples =
         self.type_name = "→".join(bases)
+        self.short_bioimageio_description = short_bioimageio_description
         self.bioimageio_description = bioimageio_description
         self.bioimageio_description_order = bioimageio_description_order
         self.bioimageio_maybe_required = bioimageio_maybe_required
         super().__init__(*super_args, **super_kwargs)  # type: ignore
 
 
-#################################################
-# fields directly derived from marshmallow fields
-#################################################
-
-
 class Array(DocumentedField, marshmallow_fields.Field):
     def __init__(self, inner: marshmallow_fields.Field, **kwargs):
         self.inner = inner
@@ -198,8 +197,15 @@ class Nested(DocumentedField, marshmallow_fields.Nested):
         if not self.bioimageio_description:
             self.bioimageio_description = self.schema.bioimageio_description
 
+        if not self.short_bioimageio_description:
+            self.short_bioimageio_description = self.schema.short_bioimageio_description
+
         repeat_type_name = self.type_name if self.bioimageio_description else ""
-        self.bioimageio_description += f" {repeat_type_name} is a Dict with the following keys:"
+        add_to_descr = f" {repeat_type_name} is a Dict with the following keys:"
+        bioimageio_description_part = self.bioimageio_description
+        self.bioimageio_description = (
+            lambda: resolve_bioimageio_descrcription(bioimageio_description_part) + add_to_descr
+        )
 
     def _deserialize(self, value, attr, data, partial=None, **kwargs):
         if not isinstance(value, dict):
@@ -255,11 +261,6 @@ class Union(DocumentedField, marshmallow_union.Union):
             raise ValidationError(message=messages, field_name=attr) from e
 
 
-#########################
-# more specialized fields
-#########################
-
-
 class Axes(String):
     def _deserialize(self, *args, **kwargs) -> str:
         axes_str = super()._deserialize(*args, **kwargs)
@@ -425,6 +426,50 @@ class RelativeLocalPath(Path):
         return super()._serialize(value, attr, obj, **kwargs)
 
 
+class BioImageIO_ID(String):
+    def __init__(
+        self,
+        *super_args,
+        bioimageio_description: typing.Union[
+            str, typing.Callable[[], str]
+        ] = "ID as shown on resource card on bioimage.io",
+        resource_type: typing.Optional[str] = None,
+        validate: typing.Optional[
+            typing.Union[
+                typing.Callable[[typing.Any], typing.Any], typing.Iterable[typing.Callable[[typing.Any], typing.Any]]
+            ]
+        ] = None,
+        **super_kwargs,
+    ):
+        from ._resolve_source import BIOIMAGEIO_COLLECTION_ENTRIES
+
+        if validate is None:
+            validate = []
+
+        if isinstance(validate, typing.Iterable):
+            validate = list(validate)
+        else:
+            validate = [validate]
+
+        if BIOIMAGEIO_COLLECTION_ENTRIES is not None:
+            error_msg = "'{input}' is not a valid BioImage.IO ID"
+            if resource_type is not None:
+                error_msg += f" of type {resource_type}"
+
+            validate.append(
+                field_validators.OneOf(
+                    {
+                        k
+                        for k, (v_type, _) in BIOIMAGEIO_COLLECTION_ENTRIES.items()
+                        if resource_type is None or resource_type == v_type
+                    },
+                    error=error_msg,
+                )
+            )
+
+        super().__init__(*super_args, bioimageio_description=bioimageio_description, **super_kwargs)
+
+
 class ProcMode(String):
     all_modes = ("fixed", "per_dataset", "per_sample")
     explanations = {
